@@ -13,7 +13,6 @@ from dsp_tools.commands.excel2json.project import excel2json
 from dsp_tools.commands.excel2json.project import old_excel2json
 from dsp_tools.commands.excel2json.properties import excel2properties
 from dsp_tools.commands.excel2json.resources import excel2resources
-from dsp_tools.commands.excel2xml.excel2xml_cli import excel2xml
 from dsp_tools.commands.id2iri import id2iri
 from dsp_tools.commands.ingest_xmlupload.create_resources.upload_xml import ingest_xmlupload
 from dsp_tools.commands.ingest_xmlupload.ingest_files.ingest_files import ingest_files
@@ -23,10 +22,8 @@ from dsp_tools.commands.project.create.project_create_lists import create_only_l
 from dsp_tools.commands.project.create.project_validate import validate_project
 from dsp_tools.commands.project.get.get import get_project
 from dsp_tools.commands.resume_xmlupload.resume_xmlupload import resume_xmlupload
-from dsp_tools.commands.rosetta import upload_rosetta
 from dsp_tools.commands.start_stack import StackConfiguration
 from dsp_tools.commands.start_stack import StackHandler
-from dsp_tools.commands.template import generate_template_repo
 from dsp_tools.commands.validate_data.validate_data import validate_data
 from dsp_tools.commands.xmlupload.upload_config import UploadConfig
 from dsp_tools.commands.xmlupload.xmlupload import xmlupload
@@ -72,8 +69,6 @@ def call_requested_action(args: argparse.Namespace) -> bool:  # noqa: PLR0912 (t
             result = _call_excel2properties(args)
         case "id2iri":
             result = _call_id2iri(args)
-        case "excel2xml":
-            result = _call_excel2xml(args)
         case "start-stack":
             result = _call_start_stack(args)
         case "stop-stack":
@@ -86,10 +81,6 @@ def call_requested_action(args: argparse.Namespace) -> bool:  # noqa: PLR0912 (t
             result = _call_ingest_files(args)
         case "ingest-xmlupload":
             result = _call_ingest_xmlupload(args)
-        case "template":
-            result = generate_template_repo()
-        case "rosetta":
-            result = upload_rosetta()
         case _:
             print(f"ERROR: Unknown action '{args.action}'")
             logger.error(f"Unknown action '{args.action}'")
@@ -117,15 +108,6 @@ def _call_start_stack(args: argparse.Namespace) -> bool:
     return stack_handler.start_stack()
 
 
-def _call_excel2xml(args: argparse.Namespace) -> bool:
-    success, _ = excel2xml(
-        datafile=args.data_source,
-        shortcode=args.project_shortcode,
-        default_ontology=args.ontology_name,
-    )
-    return success
-
-
 def _call_id2iri(args: argparse.Namespace) -> bool:
     return id2iri(
         xml_file=args.xmlfile,
@@ -204,6 +186,7 @@ def _call_ingest_xmlupload(args: argparse.Namespace) -> bool:
         interrupt_after=interrupt_after,
         skip_validation=args.skip_validation,
         skip_ontology_validation=args.skip_ontology_validation,
+        id2iri_replacement_file=args.id2iri_replacement_with_file,
     )
 
 
@@ -238,6 +221,7 @@ def _call_xmlupload(args: argparse.Namespace) -> bool:
                 ignore_duplicate_files_warning=args.ignore_duplicate_files_warning,
                 validation_severity=severity,
                 skip_ontology_validation=args.skip_ontology_validation,
+                id2iri_replacement_file=args.id2iri_replacement_with_file,
             ),
         )
 
@@ -250,6 +234,7 @@ def _call_validate_data(args: argparse.Namespace) -> bool:
         save_graphs=args.save_graphs,
         ignore_duplicate_files_warning=args.ignore_duplicate_files_warning,
         skip_ontology_validation=args.skip_ontology_validation,
+        id2iri_replacement_file=args.id2iri_replacement_with_file,
     )
 
 
