@@ -64,14 +64,8 @@ def make_parser(
 
     _add_excel2properties(subparsers)
 
-    _add_excel2xml(subparsers)
-
     _add_id2iri(subparsers)
 
-    _add_create_template(subparsers)
-
-    _add_rosetta(subparsers)
-
     _add_suppress_update_prompt(subparsers)
 
     return parser
@@ -86,21 +80,6 @@ def _add_suppress_update_prompt(subparsers: _SubParsersAction[ArgumentParser]) -
         sp.add_argument("--suppress-update-prompt", action="store_true", help=outdated_help_text)
 
 
-def _add_rosetta(subparsers: _SubParsersAction[ArgumentParser]) -> None:
-    subparser = subparsers.add_parser(
-        name="rosetta", help="Clone the most up to data rosetta repository, create the data model and upload the data"
-    )
-    subparser.set_defaults(action="rosetta")
-
-
-def _add_create_template(subparsers: _SubParsersAction[ArgumentParser]) -> None:
-    # create template repo with minimal JSON and XML files
-    subparser = subparsers.add_parser(
-        name="template", help="Create a template repository with a minimal JSON and XML file"
-    )
-    subparser.set_defaults(action="template")
-
-
 def _add_stop_stack(subparsers: _SubParsersAction[ArgumentParser]) -> None:
     subparser = subparsers.add_parser(
         name="stop-stack", help="Shut down the local instance of DSP-API and DSP-APP, and delete all data in it"
@@ -141,17 +120,6 @@ def _add_id2iri(subparsers: _SubParsersAction[ArgumentParser]) -> None:
     subparser.add_argument("mapping", help="path to the JSON file containing the mapping of IDs to IRIs")
 
 
-def _add_excel2xml(subparsers: _SubParsersAction[ArgumentParser]) -> None:
-    subparser = subparsers.add_parser(
-        name="excel2xml",
-        help="Create an XML file from an Excel/CSV file that is already structured according to the DSP specifications",
-    )
-    subparser.set_defaults(action="excel2xml")
-    subparser.add_argument("data_source", help="path to the CSV or XLS(X) file containing the data")
-    subparser.add_argument("project_shortcode", help="shortcode of the project that this data belongs to")
-    subparser.add_argument("ontology_name", help="name of the ontology that this data belongs to")
-
-
 def _add_excel2properties(subparsers: _SubParsersAction[ArgumentParser]) -> None:
     subparser = subparsers.add_parser(
         name="excel2properties",
