@@ -24,9 +24,9 @@ from dsp_tools.utils.data_formats.shared import simplify_name
 from dsp_tools.utils.data_formats.uri_util import is_iiif_uri
 from dsp_tools.utils.data_formats.uri_util import is_uri
 from dsp_tools.utils.xml_parsing.parse_clean_validate_xml import parse_and_validate_xml_file
-from dsp_tools.xmllib.helpers import find_dates_in_string as find_dates_in_string  # noqa: PLC0414 (explicit re-export)
-from dsp_tools.xmllib.helpers import make_xsd_compatible_id
-from dsp_tools.xmllib.helpers import make_xsd_compatible_id_with_uuid
+from dsp_tools.xmllib import find_dates_in_string as find_dates_in_string  # noqa: PLC0414 (explicit re-export)
+from dsp_tools.xmllib.general_functions import make_xsd_compatible_id
+from dsp_tools.xmllib.general_functions import make_xsd_compatible_id_with_uuid
 from dsp_tools.xmllib.internal.input_converters import numeric_entities
 
 # ruff: noqa: E501, UP031 (line-too-long, use f-string over percent formatting)
@@ -1930,7 +1930,7 @@ def write_xml(
     """
     warn_msg = (
         "The excel2xml lib is deprecated in favor of the xmllib. It will be removed in a future release.\n"
-        "See the xmllib docs: https://docs.dasch.swiss/latest/DSP-TOOLS/xmllib-api-reference/xmlroot/"
+        "See the xmllib docs: https://docs.dasch.swiss/latest/DSP-TOOLS/xmllib-docs/xmlroot/"
     )
     warnings.warn(DspToolsUserWarning(warn_msg))
     etree.indent(root, space="    ")
