@@ -96,6 +96,8 @@ class TriplePropertyType(Enum):
     KNORA_LICENSE = auto()
     KNORA_AUTHORSHIP = auto()
     KNORA_COPYRIGHT_HOLDER = auto()
+    KNORA_DATE_START = auto()
+    KNORA_DATE_END = auto()
 
 
 class TripleObjectType(Enum):
@@ -109,5 +111,7 @@ class TripleObjectType(Enum):
     DECIMAL = auto()
     INTEGER = auto()
     IRI = auto()
+    INTERNAL_ID = auto()
     STRING = auto()
     URI = auto()
+    DATE_YYYY_MM_DD = auto()
