@@ -1,33 +1,31 @@
 from dsp_tools.error.xmllib_warnings_util import initialise_warning_file
 
-from .helpers import ListLookup as ListLookup
-from .helpers import clean_whitespaces_from_string as clean_whitespaces_from_string
-from .helpers import create_footnote_element as create_footnote_element
-from .helpers import create_footnote_string as create_footnote_string
-from .helpers import create_list_from_input as create_list_from_input
-from .helpers import create_list_from_string as create_list_from_string
-from .helpers import create_non_empty_list_from_string as create_non_empty_list_from_string
-from .helpers import create_standoff_link_to_resource as create_standoff_link_to_resource
-from .helpers import create_standoff_link_to_uri as create_standoff_link_to_uri
-from .helpers import escape_reserved_xml_characters as escape_reserved_xml_characters
-from .helpers import find_dates_in_string as find_dates_in_string
-from .helpers import find_license_in_string as find_license_in_string
-from .helpers import get_list_nodes_from_string_via_list_name as get_list_nodes_from_string_via_list_name
-from .helpers import get_list_nodes_from_string_via_property as get_list_nodes_from_string_via_property
-from .helpers import make_xsd_compatible_id as make_xsd_compatible_id
-from .helpers import make_xsd_compatible_id_with_uuid as make_xsd_compatible_id_with_uuid
-from .helpers import reformat_date as reformat_date
-from .models.config_options import Calendar as Calendar
-from .models.config_options import DateFormat as DateFormat
-from .models.config_options import Era as Era
+from .general_functions import ListLookup as ListLookup
+from .general_functions import clean_whitespaces_from_string as clean_whitespaces_from_string
+from .general_functions import create_footnote_element as create_footnote_element
+from .general_functions import create_footnote_string as create_footnote_string
+from .general_functions import create_list_from_input as create_list_from_input
+from .general_functions import create_list_from_string as create_list_from_string
+from .general_functions import create_non_empty_list_from_string as create_non_empty_list_from_string
+from .general_functions import create_standoff_link_to_resource as create_standoff_link_to_resource
+from .general_functions import create_standoff_link_to_uri as create_standoff_link_to_uri
+from .general_functions import escape_reserved_xml_characters as escape_reserved_xml_characters
+from .general_functions import find_license_in_string as find_license_in_string
+from .general_functions import get_list_nodes_from_string_via_list_name as get_list_nodes_from_string_via_list_name
+from .general_functions import get_list_nodes_from_string_via_property as get_list_nodes_from_string_via_property
+from .general_functions import make_xsd_compatible_id as make_xsd_compatible_id
+from .general_functions import make_xsd_compatible_id_with_uuid as make_xsd_compatible_id_with_uuid
 from .models.config_options import NewlineReplacement as NewlineReplacement
-from .models.config_options import Permissions as Permissions
+from .models.date_formats import Calendar as Calendar
+from .models.date_formats import DateFormat as DateFormat
+from .models.date_formats import Era as Era
 from .models.dsp_base_resources import AudioSegmentResource as AudioSegmentResource
 from .models.dsp_base_resources import LinkResource as LinkResource
 from .models.dsp_base_resources import RegionResource as RegionResource
 from .models.dsp_base_resources import VideoSegmentResource as VideoSegmentResource
 from .models.licenses.other import LicenseOther as LicenseOther
 from .models.licenses.recommended import LicenseRecommended as LicenseRecommended
+from .models.permissions import Permissions as Permissions
 from .models.res import Resource as Resource
 from .models.root import XMLRoot as XMLRoot
 from .value_checkers import check_richtext_syntax as check_richtext_syntax
@@ -42,6 +40,8 @@ from .value_checkers import is_integer as is_integer
 from .value_checkers import is_nonempty_value as is_nonempty_value
 from .value_checkers import is_timestamp as is_timestamp
 from .value_converters import convert_to_bool_string as convert_to_bool_string
+from .value_converters import find_dates_in_string as find_dates_in_string
+from .value_converters import reformat_date as reformat_date
 from .value_converters import replace_newlines_with_br_tags as replace_newlines_with_br_tags
 from .value_converters import replace_newlines_with_paragraph_tags as replace_newlines_with_paragraph_tags
 from .value_converters import replace_newlines_with_tags as replace_newlines_with_tags
